@@ -119,6 +119,139 @@ class Acquisition(EMObject):
                 self._amplitudeContrast.get())
 
 
+class Transform(EMObject):
+    """ This class will contain a transformation matrix
+    that can be applied to 2D/3D objects like images and volumes.
+    It should contain information about euler angles, translation(or shift)
+    and mirroring.
+    Shifts are stored in pixels as treated in extract coordinates, or assign angles,...
+    """
+
+    # Basic Transformation factory
+    ROT_X_90_CLOCKWISE = 'rotX90c'
+    ROT_Y_90_CLOCKWISE = 'rotY90c'
+    ROT_Z_90_CLOCKWISE = 'rotZ90c'
+    ROT_X_90_COUNTERCLOCKWISE = 'rotX90cc'
+    ROT_Y_90_COUNTERCLOCKWISE = 'rotY90cc'
+    ROT_Z_90_COUNTERCLOCKWISE = 'rotZ90cc'
+
+    def __init__(self, matrix=None, **kwargs):
+        EMObject.__init__(self, **kwargs)
+        self._matrix = Matrix()
+        if matrix is not None:
+            self.setMatrix(matrix)
+
+    def getMatrix(self):
+        return self._matrix.getMatrix()
+
+    def getRotationMatrix(self):
+        M = self.getMatrix()
+        return M[:3, :3]
+
+    def getShifts(self):
+        M = self.getMatrix()
+        return M[1, 4], M[2, 4], M[3, 4]
+
+    def getMatrixAsList(self):
+        """ Return the values of the Matrix as a list. """
+        return self._matrix.getMatrix().flatten().tolist()
+
+    def setMatrix(self, matrix):
+        self._matrix.setMatrix(matrix)
+
+    def __str__(self):
+        return str(self._matrix)
+
+    def scale(self, factor):
+        m = self.getMatrix()
+        m *= factor
+        m[3, 3] = 1.
+
+    def scaleShifts(self, factor):
+        # By default Scipion uses a coordinate system associated with the volume rather than the projection
+        m = self.getMatrix()
+        m[0, 3] *= factor
+        m[1, 3] *= factor
+        m[2, 3] *= factor
+
+    def invert(self):
+        # Local import to avoid loop pwem --> data --> convert --> Plugin (at pwem)
+        from pwem.convert.transformations import inverse_matrix
+
+        self._matrix.setMatrix(inverse_matrix(self._matrix.getMatrix()))
+
+        return self._matrix
+
+    def getShifts(self):
+        m = self.getMatrix()
+        return m[0, 3], m[1, 3], m[2, 3]
+
+    def setShifts(self, x, y, z):
+        m = self.getMatrix()
+        m[0, 3] = x
+        m[1, 3] = y
+        m[2, 3] = z
+
+    def setShiftsTuple(self, shifts):
+        self.setShifts(shifts[0], shifts[1], shifts[2])
+
+    def composeTransform(self, matrix):
+        """Apply a transformation matrix to the current matrix """
+        new_matrix = np.matmul(matrix, self.getMatrix())
+        # new_matrix = matrix * self.getMatrix()
+        self._matrix.setMatrix(new_matrix)
+
+    @classmethod
+    def create(cls, type):
+        if type == cls.ROT_X_90_CLOCKWISE:
+            return Transform(matrix=np.array([
+                [1, 0, 0, 0],
+                [0, 0, 1, 0],
+                [0, -1, 0, 0],
+                [0, 0, 0, 1]]))
+        elif type == cls.ROT_X_90_COUNTERCLOCKWISE:
+            return Transform(matrix=np.array([
+                [1, 0, 0, 0],
+                [0, 0, -1, 0],
+                [0, 1, 0, 0],
+                [0, 0, 0, 1]]))
+        elif type == cls.ROT_Y_90_CLOCKWISE:
+            return Transform(matrix=np.array([
+                [1, 0, -1, 0],
+                [0, 1, 0, 0],
+                [1, 0, 0, 0],
+                [0, 0, 0, 1]]))
+        elif type == cls.ROT_Y_90_COUNTERCLOCKWISE:
+            return Transform(matrix=np.array([
+                [1, 0, 1, 0],
+                [0, 1, 0, 0],
+                [-1, 0, 0, 0],
+                [0, 0, 0, 1]]))
+        elif type == cls.ROT_Z_90_CLOCKWISE:
+            return Transform(matrix=np.array([
+                [0, 1, 0, 0],
+                [-1, 0, 0, 0],
+                [0, 0, 1, 0],
+                [0, 0, 0, 1]]))
+        elif type == cls.ROT_Z_90_COUNTERCLOCKWISE:
+            return Transform(matrix=np.array([
+                [0, -1, 0, 0],
+                [1, 0, 0, 0],
+                [0, 0, 1, 0],
+                [0, 0, 0, 1]]))
+        else:
+            TRANSFORMATION_FACTORY_TYPES = [
+                cls.ROT_X_90_CLOCKWISE,
+                cls.ROT_Y_90_CLOCKWISE,
+                cls.ROT_Z_90_CLOCKWISE,
+                cls.ROT_X_90_COUNTERCLOCKWISE,
+                cls.ROT_Y_90_COUNTERCLOCKWISE,
+                cls.ROT_Z_90_COUNTERCLOCKWISE
+            ]
+            raise Exception('Introduced Transformation type is not recognized.\nAdmitted values are\n'
+                            '%s' % ' '.join(TRANSFORMATION_FACTORY_TYPES))
+
+
 class CTFModel(EMObject):
     """ Represents a generic CTF model. """
 
@@ -553,7 +686,7 @@ class Image(EMObject):
     def hasTransform(self):
         return self._transform is not None
 
-    def getTransform(self):
+    def getTransform(self)-> Transform:
         return self._transform
 
     def setTransform(self, newTransform):
@@ -780,12 +913,64 @@ class EMFile(EMObject):
         """ Use the _objValue attribute to store filename. """
         self._filename.set(filename)
 
+class Alphabet():
+    """ class with a dictionary of all valid alphabets"""
+    # sequence types
+    AMINOACIDS = 0
+    NUCLEOTIDES = 1
+    
+    SEQ_TYPE = ['aminoacids', 'nucleotides']
+
+    # alphabets for proteins
+    PROTEIN_ALPHABET = 0
+    EXTENDED_PROTEIN_ALPHABET = 1
+
+    # alphabets for nucleotides
+    AMBIGOUS_DNA_ALPHABET = 2
+    UNAMBIGOUS_DNA_ALPHABET = 3
+    EXTENDED_DNA_ALPHABET = 4
+    AMBIGOUS_RNA_ALPHABET = 5
+    UNAMBIGOUS_RNA_ALPHABET = 6 
+    NUCLEOTIDES_ALPHABET = 7
+
+    # dummy alphabet
+    DUMMY_ALPHABET = 8
+
+    # dictionary with all alphabets
+    alphabets = {}; alphabetsLabels = {}
+
+    alphabets[PROTEIN_ALPHABET] = 'ACDEFGHIKLMNPQRSTVWY'
+    alphabets[EXTENDED_PROTEIN_ALPHABET] = 'ACDEFGHIKLMNPQRSTVWYBJOUXZ'
+    alphabets[AMBIGOUS_DNA_ALPHABET] = 'GATCRYWSMKHBVDN'
+    alphabets[UNAMBIGOUS_DNA_ALPHABET] = 'GATC'
+    alphabets[EXTENDED_DNA_ALPHABET] = 'GATCBDSW'
+    alphabets[AMBIGOUS_RNA_ALPHABET] = 'GAUCRYWSMKHBVDN'
+    alphabets[UNAMBIGOUS_RNA_ALPHABET] = 'GAUC'
+    alphabets[NUCLEOTIDES_ALPHABET] = 'GAC'
+    alphabets[DUMMY_ALPHABET] = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
+
+    # dictionary with all alphabets labels
+    alphabetsLabels[PROTEIN_ALPHABET] = 'Protein'
+    alphabetsLabels[EXTENDED_PROTEIN_ALPHABET] = 'Extended Protein'
+    alphabetsLabels[AMBIGOUS_DNA_ALPHABET] = 'Ambigous DNA'
+    alphabetsLabels[UNAMBIGOUS_DNA_ALPHABET] = 'Unambigous DNA'
+    alphabetsLabels[EXTENDED_DNA_ALPHABET] = 'Extended DNA'
+    alphabetsLabels[AMBIGOUS_RNA_ALPHABET] = 'Ambigous RNA'
+    alphabetsLabels[UNAMBIGOUS_RNA_ALPHABET] = 'Unambigous RNA'
+
+    
 
 class Sequence(EMObject):
     """Class containing a sequence of aminoacids/nucleotides
        Attribute names follow the biopython default ones
+            param: name: name of the sequence
+            param: sequence: string with the sequence
+            param: alphabet: integer with the alphabet to be used
+            param: isAminoacids: boolean indicating if the sequence is an aminoacid sequence
+            param: id: string with the sequence id
+            param: description: string with the sequence description
+           
     """
-
     def __init__(self, name=None, sequence=None,
                  alphabet=None, isAminoacids=True, id=None, description=None,
                  **kwargs):
@@ -853,7 +1038,7 @@ class Sequence(EMObject):
         '''Exports the sequence to the specified file'''
         import pwem.convert as emconv
         seqHandler = emconv.SequenceHandler(self.getSequence(),
-                                            isAminoacid=self.getIsAminoacids())
+                                            self._alphabet.get())
         # retrieving  args from scipion object
         seqID = self.getId() if self.getId() is not None else 'seqID'
         seqName = self.getSeqName() if self.getSeqName() is not None else 'seqName'
@@ -861,13 +1046,16 @@ class Sequence(EMObject):
         seqHandler.saveFile(seqFileName, seqID,
                             name=seqName, seqDescription=seqDescription,
                             type=None)
+                            #seqFiP12345 USER_SEQ 
+                            # Aspartate aminotransferase, mitochondrial
 
     def appendToFile(self, seqFileName):
         '''Exports the sequence to the specified file. If it already exists,
         the sequence is appended to the ones in the file'''
+        logger.info("Appending sequence to file: %s" % seqFileName)
         import pwem.convert as emconv
         seqHandler = emconv.SequenceHandler(self.getSequence(),
-                                            isAminoacid=self.getIsAminoacids())
+                                            Alphabet.DUMMY_ALPHABET)
         # retrieving  args from scipion object
         seqID = self.getId() if self.getId() is not None else 'seqID'
         seqName = self.getSeqName() if self.getSeqName() is not None else 'seqName'
@@ -1476,16 +1664,21 @@ class SetOfSequences(EMSet):
     """Set containing Sequence items."""
     ITEM_TYPE = Sequence
 
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+        self.aligned = Boolean(kwargs.get('aligned', False))
+
+
     def exportToFile(self, seqFileName):
         '''Writes the sequences in the set in the specified file'''
         for sequence in self:
             sequence.appendToFile(seqFileName)
 
-    def importFromFile(self, seqFileName, isAmino=True):
+    def importFromFile(self, seqFileName, isAmino=True, type=None):
         '''Appends elements to the set from sequences found in the specified file'''
         import pwem.convert as emconv
         seqHandler = emconv.SequenceHandler()
-        seqsDic = seqHandler.readSequencesFromFile(seqFileName, type=None, isAmino=isAmino)
+        seqsDic = seqHandler.readSequencesFromFile(seqFileName, type=type, isAmino=isAmino)
         for seqDic in seqsDic:
             newSeq = Sequence(sequence=seqDic['sequence'], id=seqDic['seqID'],
                               name=seqDic['name'], description=seqDic['description'],
@@ -1715,139 +1908,6 @@ class Matrix(Scalar):
         self._objValue = other._objValue
 
 
-class Transform(EMObject):
-    """ This class will contain a transformation matrix
-    that can be applied to 2D/3D objects like images and volumes.
-    It should contain information about euler angles, translation(or shift)
-    and mirroring.
-    Shifts are stored in pixels as treated in extract coordinates, or assign angles,...
-    """
-
-    # Basic Transformation factory
-    ROT_X_90_CLOCKWISE = 'rotX90c'
-    ROT_Y_90_CLOCKWISE = 'rotY90c'
-    ROT_Z_90_CLOCKWISE = 'rotZ90c'
-    ROT_X_90_COUNTERCLOCKWISE = 'rotX90cc'
-    ROT_Y_90_COUNTERCLOCKWISE = 'rotY90cc'
-    ROT_Z_90_COUNTERCLOCKWISE = 'rotZ90cc'
-
-    def __init__(self, matrix=None, **kwargs):
-        EMObject.__init__(self, **kwargs)
-        self._matrix = Matrix()
-        if matrix is not None:
-            self.setMatrix(matrix)
-
-    def getMatrix(self):
-        return self._matrix.getMatrix()
-
-    def getRotationMatrix(self):
-        M = self.getMatrix()
-        return M[:3, :3]
-
-    def getShifts(self):
-        M = self.getMatrix()
-        return M[1, 4], M[2, 4], M[3, 4]
-
-    def getMatrixAsList(self):
-        """ Return the values of the Matrix as a list. """
-        return self._matrix.getMatrix().flatten().tolist()
-
-    def setMatrix(self, matrix):
-        self._matrix.setMatrix(matrix)
-
-    def __str__(self):
-        return str(self._matrix)
-
-    def scale(self, factor):
-        m = self.getMatrix()
-        m *= factor
-        m[3, 3] = 1.
-
-    def scaleShifts(self, factor):
-        # By default Scipion uses a coordinate system associated with the volume rather than the projection
-        m = self.getMatrix()
-        m[0, 3] *= factor
-        m[1, 3] *= factor
-        m[2, 3] *= factor
-
-    def invert(self):
-        # Local import to avoid loop pwem --> data --> convert --> Plugin (at pwem)
-        from pwem.convert.transformations import inverse_matrix
-
-        self._matrix.setMatrix(inverse_matrix(self._matrix.getMatrix()))
-
-        return self._matrix
-
-    def getShifts(self):
-        m = self.getMatrix()
-        return m[0, 3], m[1, 3], m[2, 3]
-
-    def setShifts(self, x, y, z):
-        m = self.getMatrix()
-        m[0, 3] = x
-        m[1, 3] = y
-        m[2, 3] = z
-
-    def setShiftsTuple(self, shifts):
-        self.setShifts(shifts[0], shifts[1], shifts[2])
-
-    def composeTransform(self, matrix):
-        """Apply a transformation matrix to the current matrix """
-        new_matrix = np.matmul(matrix, self.getMatrix())
-        # new_matrix = matrix * self.getMatrix()
-        self._matrix.setMatrix(new_matrix)
-
-    @classmethod
-    def create(cls, type):
-        if type == cls.ROT_X_90_CLOCKWISE:
-            return Transform(matrix=np.array([
-                [1, 0, 0, 0],
-                [0, 0, 1, 0],
-                [0, -1, 0, 0],
-                [0, 0, 0, 1]]))
-        elif type == cls.ROT_X_90_COUNTERCLOCKWISE:
-            return Transform(matrix=np.array([
-                [1, 0, 0, 0],
-                [0, 0, -1, 0],
-                [0, 1, 0, 0],
-                [0, 0, 0, 1]]))
-        elif type == cls.ROT_Y_90_CLOCKWISE:
-            return Transform(matrix=np.array([
-                [1, 0, -1, 0],
-                [0, 1, 0, 0],
-                [1, 0, 0, 0],
-                [0, 0, 0, 1]]))
-        elif type == cls.ROT_Y_90_COUNTERCLOCKWISE:
-            return Transform(matrix=np.array([
-                [1, 0, 1, 0],
-                [0, 1, 0, 0],
-                [-1, 0, 0, 0],
-                [0, 0, 0, 1]]))
-        elif type == cls.ROT_Z_90_CLOCKWISE:
-            return Transform(matrix=np.array([
-                [0, 1, 0, 0],
-                [-1, 0, 0, 0],
-                [0, 0, 1, 0],
-                [0, 0, 0, 1]]))
-        elif type == cls.ROT_Z_90_COUNTERCLOCKWISE:
-            return Transform(matrix=np.array([
-                [0, -1, 0, 0],
-                [1, 0, 0, 0],
-                [0, 0, 1, 0],
-                [0, 0, 0, 1]]))
-        else:
-            TRANSFORMATION_FACTORY_TYPES = [
-                cls.ROT_X_90_CLOCKWISE,
-                cls.ROT_Y_90_CLOCKWISE,
-                cls.ROT_Z_90_CLOCKWISE,
-                cls.ROT_X_90_COUNTERCLOCKWISE,
-                cls.ROT_Y_90_COUNTERCLOCKWISE,
-                cls.ROT_Z_90_COUNTERCLOCKWISE
-            ]
-            raise Exception('Introduced Transformation type is not recognized.\nAdmitted values are\n'
-                            '%s' % ' '.join(TRANSFORMATION_FACTORY_TYPES))
-
-
 class Class2D(SetOfParticles):
     """ Represent a Class that groups Particles objects.
     Usually the representative of the class is another Particle
@@ -2458,10 +2518,10 @@ class FSC(EMObject):
             if float(self._y[i]) < threshold or i == dataLength-1:
                 above_res = float(self._x[i-1])
                 above_fsc = float(self._y[i-1])
-                bellow_res = float(self._x[i])
-                bellow_fsc = float(self._y[i])
+                below_res = float(self._x[i])
+                below_fsc = float(self._y[i])
                 break
-        resolution = bellow_res - ((threshold-bellow_fsc)/(above_fsc-bellow_fsc) * (bellow_res-above_res))
+        resolution = below_res - ((threshold-below_fsc)/(above_fsc-below_fsc) * (below_res-above_res))
         return "{0:.1f}".format(1/resolution)
 
 
