@@ -25,7 +25,6 @@
 # **************************************************************************
 
 # Expose many basic views
-from pyworkflow.gui.browser import FileTreeProvider, STANDARD_IMAGE_EXTENSIONS
 from .views import (DataView, ObjectView, MicrographsView, CtfView,
                     ClassesView, Classes3DView, CoordinatesObjectView,
                     ImageView, TableView)
@@ -42,15 +41,3 @@ from .viewer_chimera import (Chimera, ChimeraView, ChimeraClientView,
 from .viewer_sequence import SequenceViewer
 from .viewer_volumes import viewerProtImportVolumes
 from .showj import *
-
-# register file handlers to preview info in the Filebrowser....
-from .filehandlers import *
-register = FileTreeProvider.registerFileHandler
-register(MdFileHandler(), '.xmd', '.star', '.pos', '.ctfparam', '.doc')
-register(ParticleFileHandler(),
-         '.xmp', '.tif', '.tiff', '.spi', '.mrc', '.map', '.raw',
-         '.inf', '.dm3', '.em', '.pif', '.psd', '.spe', '.ser', '.img',
-         '.hed', *STANDARD_IMAGE_EXTENSIONS)
-register(VolFileHandler(), '.vol', '.hdf')
-register(StackHandler(), '.stk', '.mrcs', '.st', '.pif', '.dm4')
-register(ChimeraHandler(), '.bild', '.mrc', '.pdb', '.vol', 'hdf')
\ No newline at end of file
