@@ -57,6 +57,7 @@ class DataViewer(pwviewer.Viewer):
         emobj.SetOfNormalModes,
         emobj.SetOfPrincipalComponents,
         emobj.SetOfPDBs,
+        emobj.SetOfAtomStructs,
         emprot.ProtParticlePicking,
         emprot.ProtImportMovies,
         # TiltPairs related data
@@ -64,6 +65,24 @@ class DataViewer(pwviewer.Viewer):
         emobj.MicrographsTiltPair,
         emobj.ParticlesTiltPair
     ]
+    _configRegistry = dict() # Extra configuration for specific types not in this plugin (e.g.: Tomo objects)
+
+    @classmethod
+    def registerConfig(cls, type, config=None):
+        """
+        Allow registration of other objects
+        :param type: Class to register --> SetOfXXX
+        :param config: Optional, dictionary with the fields configuration, otherwise all fields will be shown.
+
+        :return: Nothing
+
+        """
+        cls._targets.append(type)
+
+        if config is None:
+            config = {MODE: MODE_MD}
+
+        cls._configRegistry[type]=config
 
     def __init__(self, **kwargs):
         pwviewer.Viewer.__init__(self, **kwargs)
@@ -78,6 +97,14 @@ class DataViewer(pwviewer.Viewer):
     def _visualize(self, obj, **kwargs):
         cls = type(obj)
 
+        # Try registry first
+        config = self._configRegistry.get(cls, None)
+
+        if config is not None:
+            fn = obj.getFileName()
+            self._addObjView(obj, fn, config)
+            return self._views
+
         if issubclass(cls, emobj.Volume):
             fn = emlib.image.ImageHandler.locationToXmipp(obj)
 
@@ -235,4 +262,7 @@ class DataViewer(pwviewer.Viewer):
         elif issubclass(cls, emobj.SetOfNormalModes):
             self._views.append(DataView(obj.getFileName()))
 
+        elif issubclass(cls, emobj.EMSet):
+            self._views.append(DataView(obj.getFileName()))
+
         return self._views
